==> haskell-servant-client-0.20-116-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant-client
version:              0.20
visibility:           public
id:                   servant-client-0.20-F8BJUA9vTIj5pZKA5DROm0
key:                  servant-client-0.20-F8BJUA9vTIj5pZKA5DROm0
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:             Automatic derivation of querying functions for servant
description:
    This library lets you derive automatically Haskell functions that
    let you query each endpoint of a <http://hackage.haskell.org/package/servant servant> webservice.

    See <http://docs.servant.dev/en/stable/tutorial/Client.html the client section of the tutorial>.

    <https://github.com/haskell-servant/servant/blob/master/servant-client/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  cf1337acb2b3173d4334a95ba4fd4b5e
exposed:              True
exposed-modules:
    Servant.Client Servant.Client.Internal.HttpClient
    Servant.Client.Internal.HttpClient.Streaming
    Servant.Client.Streaming

import-dirs:          /usr/lib/ghc-9.4.8/site-local/servant-client-0.20
library-dirs:         /usr/lib/ghc-9.4.8/site-local/servant-client-0.20
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/servant-client-0.20
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-client
hs-libraries:         HSservant-client-0.20-F8BJUA9vTIj5pZKA5DROm0
depends:
    base-4.17.2.1 base-compat-0.12.3-H9qTMlLoDHsHlMi1O3x7Rp
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    exceptions-0.10.5 http-client-0.7.18-CFL3Kym0Th6HQke3FpsCoE
    http-media-0.8.1.1-L0yJqBzsJ7HBzU8PkL0wyG
    http-types-0.12.4-HZlwMmiIHY23BwfVFTCUW1
    kan-extensions-5.2.6-6YpxuJwjLFp2BWtkpUsJWf
    monad-control-1.0.3.1-Bm33cSyu4Uq1sNtabsMyLN mtl-2.2.2
    semigroupoids-6.0.1-HPRa1TslLOs3uO6GmX4W3H
    servant-0.20.2-4unmRmNaO46DZc7gSzp5GD
    servant-client-core-0.20.2-JDDAHw9k5llIP4G7rY6C7Y stm-2.5.1.0
    text-2.0.2 time-1.12.2 transformers-0.5.6.2
    transformers-base-0.4.6-FFK8b18n3VCIGQX7cmARkw
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ

haddock-interfaces:
    /usr/share/doc/haskell-servant-client/html/servant-client.haddock

haddock-html:         /usr/share/doc/haskell-servant-client/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-client-0.20-117-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant-client
version:              0.20
visibility:           public
id:                   servant-client-0.20-FaRfPdmq9G4FJGDw3eBA74
key:                  servant-client-0.20-FaRfPdmq9G4FJGDw3eBA74
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:             Automatic derivation of querying functions for servant
description:
    This library lets you derive automatically Haskell functions that
    let you query each endpoint of a <http://hackage.haskell.org/package/servant servant> webservice.

    See <http://docs.servant.dev/en/stable/tutorial/Client.html the client section of the tutorial>.

    <https://github.com/haskell-servant/servant/blob/master/servant-client/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  2a1d6206c92a98f5e6c95ae93b2aec23
exposed:              True
exposed-modules:
    Servant.Client Servant.Client.Internal.HttpClient
    Servant.Client.Internal.HttpClient.Streaming
    Servant.Client.Streaming

import-dirs:          /usr/lib/ghc-9.4.8/site-local/servant-client-0.20
library-dirs:         /usr/lib/ghc-9.4.8/site-local/servant-client-0.20
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/servant-client-0.20
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-client
hs-libraries:         HSservant-client-0.20-FaRfPdmq9G4FJGDw3eBA74
depends:
    base-4.17.2.1 base-compat-0.12.3-H9qTMlLoDHsHlMi1O3x7Rp
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    exceptions-0.10.5 http-client-0.7.18-IlZRgefaFRpLcP3Svh4rxJ
    http-media-0.8.1.1-FZJw01iMKY2Kmhsf9xs41X
    http-types-0.12.4-L1Q49cDydVgHbqlHix9Eo1
    kan-extensions-5.2.6-5eZrzXq06lrASi56J17TRY
    monad-control-1.0.3.1-Dgt1Y0D9g7dHiYVRcvJzpl mtl-2.2.2
    semigroupoids-6.0.1-L1SyrkGv2pGGclnteZiiwF
    servant-0.20.2-FHApHGto4dO5dvFHtPn54O
    servant-client-core-0.20.2-3WBnXWMiCTPFlQVE8Qz5lz stm-2.5.1.0
    text-2.0.2 time-1.12.2 transformers-0.5.6.2
    transformers-base-0.4.6-CxMZTBPVjjqLtNtLFSFzT2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ

haddock-interfaces:
    /usr/share/doc/haskell-servant-client/html/servant-client.haddock

haddock-html:         /usr/share/doc/haskell-servant-client/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
